==> gitlab_15.9.8%2Bds1.orig.tar.xz: gitlab-foss-v15.9.8/spec/controllers/admin/instance_review_controller_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Admin::InstanceReviewController, feature_category: :service_ping do
  include UsageDataHelpers

  let(:admin) { create(:admin) }
  let(:subscriptions_instance_review_url) { Gitlab::SubscriptionPortal.subscriptions_instance_review_url }

  before do
    sign_in(admin)
  end

  context 'GET #index' do
    let!(:group) { create(:group) }
    let!(:projects) { create_list(:project, 2, group: group) }

    subject { post :index }

    context 'with usage ping enabled' do
      before do
        stub_application_setting(usage_ping_enabled: true)
        stub_usage_data_connections
        stub_database_flavor_check
        ::Gitlab::Usage::ServicePingReport.for(output: :all_metrics_values)
        subject
      end

      it 'redirects to the customers app with correct params' do
        params = { instance_review: {
          email: admin.email,
          last_name: admin.name,
          version: ::Gitlab::VERSION,
          users_count: 5,
          projects_count: 2,
          groups_count: 1,
          issues_count: 0,
          merge_requests_count: 0,
          internal_pipelines_count: 0,
          external_pipelines_count: 0,
          labels_count: 0,
          milestones_count: 0,
          snippets_count: 0,
          notes_count: 0
        } }.to_query

        expect(response).to redirect_to("#{subscriptions_instance_review_url}?#{params}")
      end
    end

    context 'with usage ping disabled' do
      before do
        stub_application_setting(usage_ping_enabled: false)
        subject
      end

      it 'redirects to the customers app with correct params' do
        params = { instance_review: {
          email: admin.email,
          last_name: admin.name,
          version: ::Gitlab::VERSION
        } }.to_query

        expect(response).to redirect_to("#{subscriptions_instance_review_url}?#{params}")
      end
    end
  end
end

==> gitlab_16.0.7%2Bds1.orig.tar.xz: gitlab-foss-v16.0.7/spec/controllers/admin/instance_review_controller_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Admin::InstanceReviewController, feature_category: :service_ping do
  include UsageDataHelpers

  let(:admin) { create(:admin) }
  let(:subscriptions_instance_review_url) { ::Gitlab::Routing.url_helpers.subscription_portal_instance_review_url }

  before do
    sign_in(admin)
  end

  context 'GET #index' do
    let!(:group) { create(:group) }
    let!(:projects) { create_list(:project, 2, group: group) }

    subject { post :index }

    context 'with usage ping enabled' do
      before do
        stub_application_setting(usage_ping_enabled: true)
        stub_usage_data_connections
        stub_database_flavor_check
        ::Gitlab::Usage::ServicePingReport.for(output: :all_metrics_values)
        subject
      end

      it 'redirects to the customers app with correct params' do
        params = { instance_review: {
          email: admin.email,
          last_name: admin.name,
          version: ::Gitlab::VERSION,
          users_count: 5,
          projects_count: 2,
          groups_count: 1,
          issues_count: 0,
          merge_requests_count: 0,
          internal_pipelines_count: 0,
          external_pipelines_count: 0,
          labels_count: 0,
          milestones_count: 0,
          snippets_count: 0,
          notes_count: 0
        } }.to_query

        expect(response).to redirect_to("#{subscriptions_instance_review_url}?#{params}")
      end
    end

    context 'with usage ping disabled' do
      before do
        stub_application_setting(usage_ping_enabled: false)
        subject
      end

      it 'redirects to the customers app with correct params' do
        params = { instance_review: {
          email: admin.email,
          last_name: admin.name,
          version: ::Gitlab::VERSION
        } }.to_query

        expect(response).to redirect_to("#{subscriptions_instance_review_url}?#{params}")
      end
    end
  end
end
